package strategy;

import java.util.List;

public class DogSearcher {

    // We can save some common default comparators to do the search in some typical ways
    private static final DogComparator ID_COMPARATOR = new IdComparator();
    private static final DogComparator NAME_COMPARATOR = new NameComparator();

    // search is specified in full generality
    public static boolean search(List<Dog> dogs, Dog targetDog, DogComparator comparator) {
        for (Dog d : dogs) {
            if (comparator.compare(targetDog, d) == 0) {
                return true;
            }
        }
        return false;
    }

    // searchById provides a default comparator to the general search
    public static boolean searchById(List<Dog> dogs, Dog targetDog) {
        return search(dogs, targetDog, ID_COMPARATOR);
    }

    // searchByName provides a default comparator to the general search
    public static boolean searchByName(List<Dog> dogs, Dog targetDog) {
        return search(dogs, targetDog, NAME_COMPARATOR);
    }

}
